CloudflareSourceUtils class

Utilities for editing cloudflare/src/index.ts.

cloudflare/src/index.tsを編集するためのユーティリティ。

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

containsFunctionCall(String source, String functionName) bool
Returns true if source contains a call to functionName.
ensureImport(String source, {required String alias, required String package}) String
Ensure the import statement of package with alias exists in source.
insertDeployFunctions(String source, List<String> functions) String?
Insert functions into the m.deploy([...]) array in source.
replaceFunctionCall(String source, String functionName, String replacement) String
Replace all calls to functionName in source with replacement.