action/cloudflare/storage library

Classes

CloudflareStorageCliAction
Cloudflare deployment process for R2 Storage.
StorageManagedStateLoadResult
Result of loading and migrating the Cloudflare Storage managed state.

Constants

storageManagedStatePath → const String
Path of the Cloudflare Storage state managed by Katana.

Functions

ensureStorageManagedStateIsGitIgnored() Future<void>
Ensures that Storage managed state is ignored by Git.
loadAndMigrateStorageManagedState(Map<String, dynamic> secrets, {String configuredSecret = "", String generateSecret()?}) Future<StorageManagedStateLoadResult>
Loads Storage state and migrates the legacy automatically managed secret.
saveStorageManagedState(Map<String, dynamic> state) Future<void>
Saves Cloudflare Storage managed state atomically.