action/cloudflare/tidb library

Classes

CloudflareTidbCliAction
Cloudflare deployment process for TiDB.

Functions

splitTidbAdditiveSchemaMigrations(String source) List<String>
Splits generated additive schema into independently deployable table jobs.
tidbGeneratedEndpointSetIsComplete(Iterable<Object?> generated, Iterable<Map<String, dynamic>> remote) bool
Returns whether every generated endpoint has a matching remote method/path.