TidbEndpointOwnershipState class

Last successfully deployed TiDB endpoints for the current project.

Constructors

TidbEndpointOwnershipState({required String appId, List<TidbManagedEndpointOwnership> endpoints = const []})
Creates an endpoint ownership state.
const
TidbEndpointOwnershipState.decode(String source)
Decodes an endpoint ownership state.
factory
TidbEndpointOwnershipState.empty()
Creates an empty ownership state.
const

Properties

appId String
TiDB Data App identifier.
final
endpoints List<TidbManagedEndpointOwnership>
Endpoints confirmed by the last successful deployment.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

belongsTo(String currentAppId) bool
Whether this state belongs to currentAppId.
encode() String
Encodes this state as stable, human-readable JSON.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
staleEndpoints({required String currentAppId, required Set<String> desiredKeys}) Iterable<TidbManagedEndpointOwnership>
Returns previously deployed endpoints that are no longer desired.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited