TidbManagedEndpointOwnership class

A TiDB Data Service endpoint owned by the current Katana project.

Constructors

TidbManagedEndpointOwnership({required String name, required String method, required String path})
Creates an owned endpoint record.
const
TidbManagedEndpointOwnership.fromJson(Map value)
Reads an owned endpoint record from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
Stable method and path key.
no setter
method String
HTTP method.
final
name String
Full TiDB endpoint resource name.
final
path String
Data Service endpoint path.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

matchesEndpoint(Map endpoint) bool
Whether this record can prove ownership of endpoint.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this record to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited