FirebaseProjectAliasSynchronizer class

Maintains flavor-specific Firebase project aliases in .firebaserc.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

restore(String source, {required String from}) String
Restores settings from from while preferring values in source.
synchronize(String source, {required String flavor, required String projectId}) String
Adds or updates one flavor alias without discarding other CLI settings.