AndroidManifestPlaceholderFinalizeCliAction class

Synchronizes Dart define placeholders in AndroidManifest with Gradle.

AndroidManifestのDart defineプレースホルダーをGradleと同期します。

Inheritance
Mixed-in types

Constructors

AndroidManifestPlaceholderFinalizeCliAction()
Synchronizes Dart define placeholders in AndroidManifest with Gradle.
const

Properties

description String
Command Description.
no setteroverride
example String?
Example of command input.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkEnabled(ExecContext context) bool
Decide whether to apply this action based on the contents of context.
override
exec(ExecContext context) Future<void>
Run command.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited