KatanaEnvironmentFixPlan class

A deterministic, idempotent migration plan for one Flutter project.

Constructors

KatanaEnvironmentFixPlan.inspect()
Inspects the current directory without changing it.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
operations List<String>
Planned operations.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply({String? flavor, String? firebaseProjectId}) Future<void>
Applies the inspected migration idempotently.
describe() String
Human-readable diagnostic output.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited