AppGradle class

Class for retrieving and saving files in android/app/build.gradle.

android/app/build.gradleのファイルを取得して保存するためのクラス。

Constructors

AppGradle()
Class for retrieving and saving files in android/app/build.gradle.

Properties

android GradleAndroid?
Data in the android section.
no setter
dependencies List<GradleDependencies>
Data in the android section.
no setter
hashCode int
The hash code for this object.
no setterinherited
imports List<GradleImport>
List of import.
no setter
isKotlin bool
Whether the file is written in Kotlin.
no setter
loadProperties List<GradleLoadProperties>
Data reading part of xxx.properties.
no setter
plugins List<GradlePlugin>
List of apply plugin.
no setter
rawData String
Original text data.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

load() Future<void>
Data loading.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() Future<void>
Data storage.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited