BuildGradle class

Class for retrieving and saving files in android/build.gradle.

android/build.gradleのファイルを取得して保存するためのクラス。

Constructors

BuildGradle()
Class for retrieving and saving files in android/build.gradle.

Properties

allProjects GradleAllprojects
Data in the allprojects section.
no setter
buildScript GradleBuildScript
Data in the buildScript section.
no setter
hashCode int
The hash code for this object.
no setterinherited
isKotlin bool
Whether the file is written in Kotlin.
no setter
rawData String
Original text data.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

load() Future<void>
Data loading.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() Future<void>
Data storage.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited