CliCommandGroup class abstract

A template for creating command groups.

コマンドグループを作成するための雛形。

Inheritance
Implementers

Constructors

CliCommandGroup()
A template for creating command groups.
const

Properties

commands Map<String, CliCommand>
Defines a list of subcommands.
no setter
description String
Command Description.
no setteroverride
example String?
Example of command input.
no setteroverride
groupDescription String
Describe the group.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exec(ExecContext context) Future<void>
Run command.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited