CliTestableCodeCommand class abstract
An abstract class for creating testable code-based command templates.
テスト可能なコードベースのコマンドの雛形を作成するための抽象クラス。
- Inheritance
-
- Object
- CliCode
- CliCodeCommand
- CliTestableCodeCommand
- Implementers
- CodeCollectionCliCommand
- CodeControllerCliCommand
- CodeDocumentCliCommand
- CodeExceptionCliCommand
- CodeLogCliCommand
- CodePageCliCommand
- CodeServerCallCliCommand
- CodeServerFirestoreTriggeredCliCommand
- CodeServerRequestCliCommand
- CodeServerScheduleCliCommand
- CodeStatefulCliCommand
- CodeStatelessCliCommand
- CodeViewFixedFormAddCliCommand
- CodeViewFixedFormCliCommand
- CodeViewFixedFormEditCliCommand
- CodeViewFixedViewCliCommand
- CodeViewGridViewCliCommand
- CodeViewListFormAddCliCommand
- CodeViewListFormCliCommand
- CodeViewListFormEditCliCommand
- CodeViewListViewCliCommand
- CodeViewNavigationCliCommand
- CodeViewPageCliCommand
- CodeViewTabCliCommand
- CodeWidgetCliCommand
Constructors
- CliTestableCodeCommand()
-
An abstract class for creating testable code-based command templates.
const
Properties
- description → String
-
Defines the outline of the code.
no setterinherited
- directory → String
-
Specify the folder where the code will be generated.
no setterinherited
- example → String?
-
Example of command input.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Defines the name of the code.
no setterinherited
- prefix → String
-
Defines the code prefix.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- testDirectory → String
-
Specify the folder where test code is to be generated.
no setter
Methods
-
body(
String path, String baseName, String className) → String -
Defines the actual body code.
pathis passed relative tolib,baseNameis the filename, andclassNameis the filename converted to Pascal case.inherited -
exec(
ExecContext context) → Future< void> -
Run command.
inherited
-
filter(
String value) → String -
Filter the code.
inherited
-
generateDartCode(
String path, String className, {String ext = "dart", String filter(String value)?}) → Future< void> -
Generate Dart code in
path.inherited -
generateDartTestCode(
String path, String className, {String ext = "dart", String filter(String value)?}) → Future< void> -
Generate Dart test code in
path. -
generateFile(
String fileName, {String filter(String value)?}) → Future< void> -
Create a specific file in directory/
fileName.inherited -
header(
String path, String baseName, String className) → String -
Defines the actual header code.
pathis passed relative tolib,baseNameis the filename, andclassNameis the filename converted to Pascal case.inherited -
import(
String path, String baseName, String className) → String -
Define the actual import code.
pathis passed relative tolib,baseNameis the filename, andclassNameis the filename converted to Pascal case.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
test(
String path, String sourcePath, String baseName, String className) → String -
Define test code. The path
pathis passed relative tolib,sourcePathis the source file path,baseNameis the filename, andclassNameis the filename converted to Pascal case. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited