GradleAllprojects class

Data in the allprojects section.

allprojectsセクションのデータ。

Constructors

GradleAllprojects({required List<GradleAllprojectsConfigurations> configurations})
Data in the allprojects section.

Properties

configurations List<GradleAllprojectsConfigurations>
Data in the configurations.all section.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited