GradleAndroidSourceSet class

Source setting.

ソースの設定。

Constructors

GradleAndroidSourceSet({required String source, required String target, required String symbol})
Source setting.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
Path of the source data.
getter/setter pair
symbol String
Additive Method.
getter/setter pair
target String
Source Target.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited