PBXFileReference class

FileReference data.

FileReferenceのデータ。

Constructors

PBXFileReference({required String path, required String comment, required String sourceTree, String? id, String? lastKnownFileType, String? name, String? explicitFileType, int? fileEncoding, int? includeInIndex})
FileReference data.
factory

Properties

comment String
Comment Data.
final
explicitFileType String?
Data of explicitFileType.
final
fileEncoding int?
File encoding number.
final
hashCode int
The hash code for this object.
no setterinherited
id String
ID of the section.
final
includeInIndex int?
Data for includeInIndex.
final
isa String
Value of isa.
final
lastKnownFileType String?
lastKnownFileType information.
final
name String?
File Name.
final
path String
File Path.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceTree String
SourceTree data.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited