PBXFrameworksBuildPhase class

FrameworksBuildPhase data.

FrameworksBuildPhaseのデータ。

Constructors

PBXFrameworksBuildPhase({required String buildActionMask, required List<PBXFrameworksBuildPhaseFiles> files, String? id, String? comment, int? runOnlyForDeploymentPostprocessing})
FrameworksBuildPhase data.
factory

Properties

buildActionMask String?
BuildActionMask data.
final
comment String?
Comment Data.
final
files List<PBXFrameworksBuildPhaseFiles>
Data for PBXFrameworksBuildPhaseFiles.
final
hashCode int
The hash code for this object.
no setterinherited
id String
ID of the section.
final
isa String
Value of isa.
final
runOnlyForDeploymentPostprocessing int?
Data from runOnlyForDeploymentPostprocessing.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited