PBXVariantGroupChild class

Data for children in PBXVariantGroup.

PBXVariantGroupchildrenのデータ。

Constructors

PBXVariantGroupChild({required String comment, String? id})
Data for children in PBXVariantGroup.
factory

Properties

comment String
Comment Data.
final
hashCode int
The hash code for this object.
no setterinherited
id String
ID of the element.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(String text) List<PBXVariantGroupChild>
Parse the text to PBXVariantGroupChild.