StorageManagedStateLoadResult class
Result of loading and migrating the Cloudflare Storage managed state.
Constructors
Properties
- downloadUrlSecret → String
-
Secret used to sign limited download URLs.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretsChanged → bool
-
Whether
katana_secrets.yamlwas changed by migration.final -
state
→ Map<
String, dynamic> -
Storage state stored in storageManagedStatePath.
final
- stateChanged → bool
-
Whether storageManagedStatePath must be persisted.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited