TidbCloudManagementApi class
Minimal Digest-authenticated client for TiDB Cloud management APIs.
- Implemented types
Constructors
- TidbCloudManagementApi({required String publicKey, required String privateKey})
- Creates a management API client.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- privateKey → String
-
TiDB Cloud organization API private key.
final
- publicKey → String
-
TiDB Cloud organization API public key.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the underlying HTTP client.
-
dataService(
String method, String path, {Map< String, String> ? query, Object? body}) → Future<Map< String, dynamic> > -
Sends a Data Service management API request.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
request(
String method, Uri uri, {Object? body}) → Future< Map< String, dynamic> > - Sends a Digest-authenticated request.
-
starter(
String method, String path, {Map< String, String> ? query, Object? body}) → Future<Map< String, dynamic> > - Sends a Starter management API request.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited