TidbManagedStateLoadResult class
Result of loading and migrating the TiDB managed state.
Constructors
-
TidbManagedStateLoadResult({required Map<
String, dynamic> state, required bool secretsChanged, required bool stateChanged}) -
Creates a result of loading and migrating the TiDB managed state.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretsChanged → bool
-
Whether
katana_secrets.yamlwas changed by migration.final -
state
→ Map<
String, dynamic> -
Flavor-specific TiDB state stored under
cloudflare/.final - stateChanged → bool
-
Whether the flavor-specific state must be persisted.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited