FirebaseFunctionsToolingPlan class
Command plan for initializing Firebase Functions development tooling.
Firebase Functionsの開発ツールを初期化するためのコマンド計画。
Constructors
- FirebaseFunctionsToolingPlan.create({required Directory functionsDirectory})
-
Creates a command plan based on the current Functions directory.
factory
Properties
-
fixLintCommand
→ List<
String> -
Command that fixes ESLint errors.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initializeJest → bool
-
Whether a Jest configuration must be generated.
final
-
initializeJestCommand
→ List<
String> -
Command that generates the Jest configuration.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited