CliMcpCode class abstract
Abstract class for defining MCP code.
MCPコードを定義するための抽象クラス。
Constructors
- CliMcpCode()
-
Abstract class for defining MCP code.
const
Properties
- description → String
-
Define the description of the code.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Define the name of the code.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
ExecContext context) → bool -
Defines whether to apply this code based on the contents of
context. -
body(
ExecContext context) → DynamicMap - Defines the actual body code.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited