PBXBuildConfiguration class
BuildConfiguration data.
BuildConfigurationのデータ。
Constructors
-
PBXBuildConfiguration({required List<
PBXBuildConfigurationSettings> buildSettings, required String name, required String baseConfigurationReference, String? id, String? comment}) -
BuildConfiguration data.
factory
Properties
- baseConfigurationReference → String?
-
Data from
baseConfigurationReference.final -
buildSettings
→ List<
PBXBuildConfigurationSettings> -
List of data in the group.
final
- comment → String?
-
Comment Data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
ID of the section.
final
- isa → String
-
Value of
isa.final - name → String
-
Setting Name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited