PBXFileReference class
FileReference data.
FileReferenceのデータ。
Constructors
Properties
- comment → String
-
Comment Data.
final
- explicitFileType → String?
-
Data of
explicitFileType.final - fileEncoding → int?
-
File encoding number.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
ID of the section.
final
- includeInIndex → int?
-
Data for
includeInIndex.final - isa → String
-
Value of
isa.final - lastKnownFileType → String?
-
lastKnownFileTypeinformation.final - name → String?
-
File Name.
final
- path → String
-
File Path.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceTree → String
-
SourceTree data.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited